/***************************************************************
 * Name:      spincontrol.cpp
 * Purpose:   Code for Dialog spinControl
 * Author:    Salvador Pozo (salvapozo@gmail.com)
 * Created:   2024-11-07
 * Copyright: Salvador Pozo (https://conclase.net)
 * License:
 **************************************************************/

#include "spincontrol.h"

wxBEGIN_EVENT_TABLE(spinControl, wxDialog)
    EVT_CLOSE(spinControl::OnClose)
    EVT_BUTTON(wxID_OK, spinControl::OnOk)
wxEND_EVENT_TABLE()

spinControl::spinControl(wxWindow *wnd, datos &datos)
    : wxDialog(wnd, -1, _T("Ejemplo edición de números")), data(datos)
{
    wxBoxSizer *boxVertical;
    wxBoxSizer *boxHorizontal;

    boxVertical = new wxBoxSizer(wxVERTICAL);

    boxHorizontal = new wxBoxSizer(wxHORIZONTAL);
    m_spinCtrl = new wxSpinCtrl(this, idSpinCtrl, wxEmptyString, wxDefaultPosition, wxSize(200, wxDefaultCoord), 0, 0, 100, datos.entero);
    boxHorizontal->Add(new wxStaticText(this, wxID_ANY, _T("&Entero:")), wxSizerFlags().Border());
    boxHorizontal->Add(m_spinCtrl, wxSizerFlags().Border());
    boxVertical->Add(boxHorizontal, wxSizerFlags().Border(wxTOP).Right());
    m_spinCtrl->SetIncrement(2);
    m_spinCtrl->SetRange(6, 90);
    m_spinCtrl->SetValue(45);

    boxHorizontal = new wxBoxSizer(wxHORIZONTAL);
    m_spinCtrlHexadecimal = new wxSpinCtrl(this, idSpinCtrl, wxEmptyString, wxDefaultPosition, wxSize(200, wxDefaultCoord), 0, 0, 255, datos.hexadecimal);
    boxHorizontal->Add(new wxStaticText(this, wxID_ANY, _T("&Hexadecimal:")), wxSizerFlags().Border());
    boxHorizontal->Add(m_spinCtrlHexadecimal, wxSizerFlags().Border());
    boxVertical->Add(boxHorizontal, wxSizerFlags().Border(wxTOP).Right());
    m_spinCtrlHexadecimal->SetBase(16);

    boxHorizontal = new wxBoxSizer(wxHORIZONTAL);
    m_spinCtrlDouble = new wxSpinCtrlDouble(this, idSpinCtrlDouble, wxEmptyString, wxDefaultPosition, wxSize(200, wxDefaultCoord), 0, 0.0, 5.0, datos.doble, 0.001);
    m_spinCtrlDouble->SetIncrement(0.01);
    m_spinCtrlDouble->SetDigits(4);
    boxHorizontal->Add(new wxStaticText(this, wxID_ANY, _T("Punto flotante:")), wxSizerFlags().Border());
    boxHorizontal->Add(m_spinCtrlDouble, wxSizerFlags().Border());
    boxVertical->Add(boxHorizontal, wxSizerFlags().Border(wxTOP).Right());

    boxVertical->Add(CreateStdDialogButtonSizer(wxOK | wxCANCEL), wxSizerFlags().Border());

    SetSizerAndFit(boxVertical);
}

spinControl::~spinControl()
{
    //dtor
}

void spinControl::OnClose(wxCloseEvent& event) {
    Destroy();
}

void spinControl::OnOk(wxCommandEvent& event) {
    data.entero = m_spinCtrl->GetValue();
    data.hexadecimal = m_spinCtrlHexadecimal->GetValue();
    data.doble = m_spinCtrlDouble->GetValue();
    Destroy();
}
