/***************************************************************
 * Name:      wx006Main.cpp
 * Purpose:   Code for Application Frame
 * Author:    Salvador Pozo (salvador@conclase.net)
 * Created:   2024-11-07
 * Copyright: Salvador Pozo (https://conclase.net)
 * License:
 **************************************************************/

#ifdef WX_PRECOMP
#include "wx_pch.h"
#endif

#include "wx006Main.h"
#include "spincontrol.h"

//helper functions
enum wxbuildinfoformat {
    short_f, long_f };

wxString wxbuildinfo(wxbuildinfoformat format)
{
    wxString wxbuild(wxVERSION_STRING);

    if (format == long_f )
    {
#if defined(__WXMSW__)
        wxbuild << _T("-Windows");
#elif defined(__WXMAC__)
        wxbuild << _T("-Mac");
#elif defined(__UNIX__)
        wxbuild << _T("-Linux");
#endif

#if wxUSE_UNICODE
        wxbuild << _T("-Unicode build");
#else
        wxbuild << _T("-ANSI build");
#endif // wxUSE_UNICODE
    }

    return wxbuild;
}

BEGIN_EVENT_TABLE(wx006Frame, wxFrame)
    EVT_CLOSE(wx006Frame::OnClose)
    EVT_MENU(idDialogo, wx006Frame::OnDialogo)
    EVT_MENU(idMenuQuit, wx006Frame::OnQuit)
    EVT_MENU(idMenuAbout, wx006Frame::OnAbout)
END_EVENT_TABLE()

wx006Frame::wx006Frame(wxFrame *frame, const wxString& title)
    : wxFrame(frame, -1, title)
{
    // create a menu bar
    wxMenuBar* mbar = new wxMenuBar();
    wxMenu* fileMenu = new wxMenu(_T(""));
    fileMenu->Append(idDialogo, _T("&Leer datos\tF2"), _T("Lectura de datos"));
    fileMenu->Append(idMenuQuit, _T("&Salir\tAlt-F4"), _T("Cerrar la aplicación"));
    mbar->Append(fileMenu, _T("&Fichero"));

    wxMenu* helpMenu = new wxMenu(_T(""));
    helpMenu->Append(idMenuAbout, _T("&Sobre\tF1"), _T("Mostrar información sobre esta aplicación"));
    mbar->Append(helpMenu, _T("&Ayuda"));

    SetMenuBar(mbar);

    // create a status bar with some information about the used wxWidgets version
    CreateStatusBar(2);
    SetStatusText(_T("Hola usuario"),0);
    SetStatusText(wxbuildinfo(short_f), 1);
}


wx006Frame::~wx006Frame()
{
}

void wx006Frame::OnClose(wxCloseEvent &event)
{
    Destroy();
}

void wx006Frame::OnQuit(wxCommandEvent &event)
{
    Destroy();
}

void wx006Frame::OnAbout(wxCommandEvent &event)
{
    wxString msg = wxbuildinfo(long_f);
    wxMessageBox(msg, _T("Bienvenido a ..."));
}

void wx006Frame::OnDialogo(wxCommandEvent &event)
{
    datos data(10, 0x7f, 0.002);
    wxString cad;
    spinControl *dlg = new spinControl(this, data);
    dlg->ShowModal();

    cad << _T("Entero: ") << data.entero << "\n";
    cad << _T("Hexadecimal: ") << data.hexadecimal << "\n";
    cad << _T("Flotante: ") << data.doble;

    wxMessageBox(cad, _T("Respuesta"));
}
